import { defineComponent, ref, computed, createVNode, Fragment, resolveComponent, mergeProps } from 'vue';
import { inputProps } from './type.mjs';
import { DocumentCopy } from '@element-plus/icons-vue';
import { ElInput, ElMessage } from 'element-plus';
import '../../../utils/index.mjs';
import { copyText } from '../../../utils/tools.mjs';

var Input = defineComponent({
  name: "BcInput",
  props: inputProps,
  inheritAttrs: false,
  components: {
    DocumentCopy,
    ElInput
  },
  setup(props, context) {
    const inputRef = ref();
    const inputWidth = computed(() => {
      if (typeof props.width === "number") {
        return `${props.width}px`;
      }
      return props.width;
    });
    const borderClass = {
      none: "no-border",
      bottom: "bottom-border",
      all: ""
    }[props.border];
    const copyOptions = typeof props.copy === "boolean" ? {
      size: 20
    } : props.copy;
    const suffix = () => {
      var _a, _b;
      return createVNode(Fragment, null, [props.copy && createVNode(resolveComponent("el-tooltip"), {
        "content": "\u590D\u5236"
      }, {
        default: () => {
          var _a2;
          return [createVNode(resolveComponent("el-icon"), {
            "style": "cursor: pointer",
            "size": (_a2 = copyOptions.size) != null ? _a2 : 20,
            "color": copyOptions.color,
            "onClick": handleCopy
          }, {
            default: () => {
              var _a3, _b2, _c;
              return [(_c = (_b2 = (_a3 = context.slots).icon) == null ? void 0 : _b2.call(_a3)) != null ? _c : createVNode(resolveComponent("document-copy"), null, null)];
            }
          })];
        }
      }), (_b = (_a = context.slots).suffix) == null ? void 0 : _b.call(_a)]);
    };
    async function handleCopy() {
      var _a, _b;
      if (inputRef.value) {
        const text = (_b = (_a = inputRef.value.input) == null ? void 0 : _a.value) != null ? _b : "";
        await copyText(String(text));
        ElMessage.success("\u590D\u5236\u6210\u529F");
      }
    }
    return {
      inputRef,
      borderClass,
      inputWidth,
      suffix
    };
  },
  render() {
    const input = () => createVNode(resolveComponent("el-input"), mergeProps({
      "ref": (el) => this.inputRef = el,
      "class": ["bc-input", this.borderClass],
      "style": {
        width: this.inputWidth
      },
      "placeholder": "\u8BF7\u8F93\u5165",
      "spellcheck": false
    }, this.$attrs), {
      ...this.$slots,
      suffix: this.suffix
    });
    const text = () => createVNode("span", null, [this.$attrs.modelValue]);
    return this.onlyDisplay ? text() : input();
  }
});

export { Input as default };
//# sourceMappingURL=input.mjs.map
