import { defineComponent, ref, withDirectives, createVNode, resolveComponent, mergeProps, resolveDirective } from 'vue';

var cellEdit = defineComponent({
  name: "BcTableCellEdit",
  emits: ["save", "blur"],
  directives: {
    focus: {
      mounted: (el) => {
        el.querySelector("input").focus();
      }
    }
  },
  props: {
    modelValue: {
      type: [String, Number],
      default: ""
    },
    unit: String
  },
  setup(props, context) {
    const editing = ref(false);
    const cell = ref("");
    const inputRef = ref();
    function toggleEdit() {
      editing.value = !editing.value;
    }
    function save() {
      context.emit("save", cell.value);
      const el = inputRef.value.$el;
      el == null ? void 0 : el.querySelector("input").blur();
    }
    const editInput = () => withDirectives(createVNode(resolveComponent("bc-input"), mergeProps({
      "class": "bc-table-input",
      "ref": inputRef,
      "model-value": cell.value
    }, {
      "onUpdate:modelValue": (val) => {
        cell.value = val;
      },
      onFocus: () => {
        cell.value = props.modelValue;
      },
      onBlur: () => {
        toggleEdit();
        context.emit("blur", cell.value);
      },
      onKeyup: (e) => {
        e.code === "Enter" && save();
      }
    }), {
      suffix: props.unit ? createVNode("span", null, [props.unit]) : null
    }), [[resolveDirective("focus")]]);
    const displayInput = () => createVNode("div", {
      "class": "bc-table-cell-edit",
      "onClick": toggleEdit
    }, [props.modelValue]);
    return () => editing.value ? editInput() : displayInput();
  }
});

export { cellEdit as default };
//# sourceMappingURL=cellEdit.mjs.map
