import { defineComponent, ref, computed, createElementVNode, createTextVNode, resolveComponent, resolveDirective, openBlock, createBlock, withCtx, withDirectives, createElementBlock, createVNode, Fragment, createCommentVNode } from 'vue';
import { uploadProps } from './type.mjs';
import { Plus } from '@element-plus/icons-vue';
import _export_sfc from '../../../_virtual/plugin-vue_export-helper.mjs';

const _sfc_main = defineComponent({
  name: "BcUpload",
  emits: ["update:modelValue", "success", "error"],
  props: uploadProps,
  components: {
    Plus
  },
  setup(props, context) {
    const uploading = ref(false);
    const uploadRef = ref();
    const dialogVisible = computed({
      get() {
        return props.modelValue;
      },
      set(visible) {
        context.emit("update:modelValue", visible);
      }
    });
    function uploadFile(options) {
      uploading.value = true;
      const upload = uploadRef.value;
      const form = new FormData();
      let callbackData;
      switch (props.callbackType) {
        case "file":
          callbackData = options.file;
          break;
        case "raw":
          callbackData = options;
          break;
        default:
          form.append("file", options.file);
          callbackData = form;
      }
      props.uploadApi?.(callbackData).then(() => {
        uploading.value = false;
        context.emit("success");
        context.emit("update:modelValue", false);
      }).catch(() => {
        uploading.value = false;
        context.emit("error");
      }).finally(() => {
        upload.clearFiles();
      });
    }
    function handleDownloadTemplate() {
      props.templateApi?.();
    }
    return {
      dialogVisible,
      uploading,
      uploadRef,
      uploadFile,
      handleDownloadTemplate
    };
  }
});
const _hoisted_1 = { class: "text-center" };
const _hoisted_2 = /* @__PURE__ */ createElementVNode("span", null, "\u60A8\u662F\u5426\u6709\u6807\u51C6\u7684Excel\u6A21\u7248\uFF0C\u9700\u8981\u4F9D\u7167\u6A21\u7248\u5BFC\u5165\uFF0C\u5426\u5219\u4F1A\u5931\u8D25\u3002", -1);
const _hoisted_3 = /* @__PURE__ */ createElementVNode("br", null, null, -1);
const _hoisted_4 = /* @__PURE__ */ createElementVNode("div", { class: "el-upload__text" }, [
  /* @__PURE__ */ createTextVNode("\u5C06\u6587\u4EF6\u62D6\u5230\u6B64\u5904\uFF0C\u6216"),
  /* @__PURE__ */ createElementVNode("em", null, "\u70B9\u51FB\u4E0A\u4F20")
], -1);
const _hoisted_5 = {
  key: 1,
  class: "el-upload-dragger"
};
const _hoisted_6 = /* @__PURE__ */ createElementVNode("div", { class: "el-upload__text" }, [
  /* @__PURE__ */ createElementVNode("em", null, "\u70B9\u51FB\u4E0A\u4F20")
], -1);
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_el_link = resolveComponent("el-link");
  const _component_el_alert = resolveComponent("el-alert");
  const _component_plus = resolveComponent("plus");
  const _component_el_icon = resolveComponent("el-icon");
  const _component_el_upload = resolveComponent("el-upload");
  const _component_bc_dialog = resolveComponent("bc-dialog");
  const _directive_loading = resolveDirective("loading");
  return openBlock(), createBlock(_component_bc_dialog, {
    width: "480px",
    modelValue: _ctx.dialogVisible,
    "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => _ctx.dialogVisible = $event),
    title: "\u6587\u4EF6\u5BFC\u5165",
    "append-to-body": "",
    noFooter: ""
  }, {
    default: withCtx(() => [
      withDirectives((openBlock(), createElementBlock("section", null, [
        createVNode(_component_el_alert, {
          type: "warning",
          closable: false
        }, {
          default: withCtx(() => [
            createElementVNode("div", _hoisted_1, [
              _hoisted_2,
              _hoisted_3,
              createVNode(_component_el_link, {
                type: "primary",
                onClick: _ctx.handleDownloadTemplate
              }, {
                default: withCtx(() => [
                  createTextVNode("\u8FD8\u6CA1\u6709Excel\u6A21\u7248?\u8BF7\u4E0B\u8F7D\u6A21\u7248")
                ]),
                _: 1
              }, 8, ["onClick"])
            ])
          ]),
          _: 1
        }),
        createVNode(_component_el_upload, {
          style: { "text-align": "center", "margin-top": "20px" },
          action: "",
          ref: "uploadRef",
          "show-file-list": false,
          "with-credentials": "",
          httpRequest: _ctx.uploadFile,
          accept: ".xlsx,.xls",
          drag: _ctx.drag
        }, {
          default: withCtx(() => [
            _ctx.drag ? (openBlock(), createElementBlock(Fragment, { key: 0 }, [
              createVNode(_component_el_icon, { class: "el-icon--upload" }, {
                default: withCtx(() => [
                  createVNode(_component_plus)
                ]),
                _: 1
              }),
              _hoisted_4
            ], 64)) : (openBlock(), createElementBlock("div", _hoisted_5, [
              createVNode(_component_el_icon, { class: "el-icon--upload" }, {
                default: withCtx(() => [
                  createVNode(_component_plus)
                ]),
                _: 1
              }),
              _hoisted_6
            ])),
            createCommentVNode(' <div class="el-upload__tip" slot="tip">\u53EA\u80FD\u4E0A\u4F20excel\u6587\u4EF6</div> ')
          ]),
          _: 1
        }, 8, ["httpRequest", "drag"])
      ])), [
        [_directive_loading, _ctx.uploading]
      ])
    ]),
    _: 1
  }, 8, ["modelValue"]);
}
var Upload = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);

export { Upload as default };
//# sourceMappingURL=upload.mjs.map
