'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var elementPlus = require('element-plus');
var type = require('./type.js');

var Button = vue.defineComponent({
  name: "BcButton",
  emits: ["click"],
  props: type.buttonProps,
  components: {
    ElButton: elementPlus.ElButton,
    ElTooltip: elementPlus.ElTooltip
  },
  setup(props, context) {
    function handleClick(event) {
      if (props.confirm || props.type === "delete" || props.type === "danger") {
        const confirmText = typeof props.confirm === "boolean" ? "\u6B64\u64CD\u4F5C\u65E0\u6CD5\u64A4\u9500\uFF0C\u662F\u5426\u7EE7\u7EED\uFF1F" : props.confirm;
        elementPlus.ElMessageBox.confirm(confirmText, "\u8B66\u544A", {
          confirmButtonText: "\u786E\u5B9A",
          cancelButtonText: "\u53D6\u6D88",
          type: "warning"
        }).then(() => {
          context.emit("click", event);
        }).catch(() => ({}));
      } else {
        context.emit("click", event);
      }
    }
    const tooltip = (node) => vue.createVNode(vue.resolveComponent("el-tooltip"), {
      "placement": "top"
    }, {
      default: () => [vue.createVNode("span", null, [node()])],
      content: () => {
        var _a, _b;
        return vue.createVNode("span", null, [(_b = (_a = context.slots).default) == null ? void 0 : _b.call(_a)]);
      }
    });
    const spanContent = !props.tooltip ? context.slots.default || null : null;
    const button = () => vue.createVNode(vue.resolveComponent("el-button"), vue.mergeProps({
      "class": ["bc-button", {
        mini: props.mini
      }]
    }, {
      ...context.attrs,
      type: props.type,
      tooltip: props.tooltip,
      onClick: handleClick
    }), {
      default: () => [vue.createVNode("span", null, [spanContent == null ? void 0 : spanContent()])]
    });
    const iconButton = () => vue.createVNode(vue.resolveComponent("el-button"), vue.mergeProps({
      "class": ["bc-button", {
        mini: props.mini
      }]
    }, {
      ...context.attrs,
      type: props.type,
      tooltip: props.tooltip,
      onClick: handleClick
    }), null);
    return () => context.slots.default && props.tooltip ? tooltip(iconButton) : context.attrs.icon ? iconButton() : button();
  }
});

exports["default"] = Button;
//# sourceMappingURL=button.js.map
