'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var elementPlus = require('element-plus');
var iconsVue = require('@element-plus/icons-vue');

var Dialog = vue.defineComponent({
  name: "BcDialog",
  emits: ["update:modelValue", "cancel", "submit"],
  props: {
    noFooter: Boolean,
    needFullscreen: Boolean
  },
  components: {
    ElDialog: elementPlus.ElDialog,
    FullScreen: iconsVue.FullScreen
  },
  setup(props, context) {
    const fullscreen = vue.ref(false);
    const isFullscreen = vue.computed(() => {
      if (props.needFullscreen) {
        return fullscreen.value;
      } else {
        return !!context.attrs.fullscreen || context.attrs.fullscreen === "";
      }
    });
    fullscreen.value = !!context.attrs.fullscreen;
    function handleFullScreen() {
      fullscreen.value = !fullscreen.value;
    }
    function handleCancel() {
      context.emit("update:modelValue", false);
      context.emit("cancel");
    }
    const footer = () => vue.createVNode("footer", null, [vue.createVNode(vue.resolveComponent("el-button"), {
      "onClick": handleCancel
    }, {
      default: () => [vue.createTextVNode("\u53D6\u6D88")]
    }), vue.createVNode(vue.resolveComponent("el-button"), {
      "onClick": () => context.emit("submit")
    }, {
      default: () => [vue.createTextVNode("\u786E\u8BA4")]
    })]);
    const header = () => {
      var _a, _b, _c, _d, _e, _f;
      return vue.createVNode("header", {
        "class": "bc-dialog-header"
      }, [(_f = (_e = (_b = (_a = context.slots).header) == null ? void 0 : _b.call(_a)) != null ? _e : (_d = (_c = context.slots).title) == null ? void 0 : _d.call(_c)) != null ? _f : vue.createVNode("span", {
        "class": "text"
      }, [context.attrs.title]), props.needFullscreen && vue.createVNode(vue.resolveComponent("el-icon"), {
        "onClick": handleFullScreen,
        "style": "cursor: pointer;"
      }, {
        default: () => [vue.createVNode(vue.resolveComponent("full-screen"), null, null)]
      })]);
    };
    const dialog = () => vue.createVNode(vue.resolveComponent("el-dialog"), vue.mergeProps({
      "close-on-click-modal": false,
      "fullscreen": fullscreen.value
    }, {
      "onUpdate:modelValue": (visible) => context.emit("update:modelValue", visible)
    }, context.attrs), {
      default: () => [vue.createVNode(vue.resolveComponent("el-scrollbar"), {
        "ref": "scrollbar",
        "class": ["bc-dialog-scrollbar", {
          "bc-dialog-is-fullscreen": isFullscreen.value
        }]
      }, {
        default: () => {
          var _a, _b;
          return [(_b = (_a = context.slots).default) == null ? void 0 : _b.call(_a)];
        }
      })],
      header,
      footer: () => {
        var _a, _b;
        return !props.noFooter && (((_b = (_a = context.slots) == null ? void 0 : _a.footer) == null ? void 0 : _b.call(_a)) || footer());
      }
    });
    return dialog;
  }
});

exports["default"] = Dialog;
//# sourceMappingURL=dialog.js.map
