'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
require('../../../hooks/index.js');
var type = require('./type.js');
require('../../../utils/index.js');
var index = require('../../button/index.js');
var index$1 = require('../../upload/index.js');
var elementPlus = require('element-plus');
var useConfigInject = require('../../../hooks/useConfigInject.js');
var tools = require('../../../utils/tools.js');
var renderUnit = require('../../../utils/renderUnit.js');

function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !vue.isVNode(s);
}
var Search = vue.defineComponent({
  name: "BcSearch",
  props: type.searchProps,
  emits: ["update:modelValue", "reset", "create", "export"],
  components: {
    BcButton: index.BcButton,
    ElForm: elementPlus.ElForm,
    ElFormItem: elementPlus.ElFormItem,
    BcUpload: index$1.BcUpload
  },
  setup(props, context) {
    var _a, _b;
    const searchInject = useConfigInject.useConfigInject("search", props).search;
    const {
      pageName: tablePageName
    } = useConfigInject.useConfigInject("table", props);
    const pageName = (_a = searchInject == null ? void 0 : searchInject.pageName) != null ? _a : tablePageName.value;
    const needExport = (_b = searchInject == null ? void 0 : searchInject.export) != null ? _b : props.export;
    const instance = vue.getCurrentInstance();
    const uploadVisible = vue.ref(false);
    const searchConfig = vue.ref();
    const defaultParams = vue.ref();
    vue.watch(() => props.config, (config) => {
      searchConfig.value = [...config];
    }, {
      immediate: true,
      deep: true
    });
    vue.watch(() => props.defaultValue, (value) => {
      defaultParams.value = JSON.parse(JSON.stringify({
        ...props.modelValue,
        ...value
      }));
      context.emit("update:modelValue", JSON.parse(JSON.stringify({
        ...props.modelValue,
        ...defaultParams.value
      })));
    }, {
      immediate: true
    });
    function updateData(key, val) {
      const modelValue = {
        ...props.modelValue
      };
      tools.setValue(modelValue, key, val);
      context.emit("update:modelValue", modelValue);
    }
    function handleUpload() {
      uploadVisible.value = true;
    }
    function handleSubmit(e) {
      e.preventDefault();
    }
    function handleSearch(params) {
      var _a2;
      context.emit("update:modelValue", {
        ...props.modelValue,
        ...params instanceof MouseEvent ? {} : params,
        [pageName]: 1
      });
      (_a2 = props.search) == null ? void 0 : _a2.call(props);
    }
    function handleReset() {
      var _a2;
      const params = {
        ...defaultParams.value
      };
      for (const key in props.modelValue) {
        const whiteList = Object.keys(params);
        if (!whiteList.includes(key)) {
          params[key] = Array.isArray(props.modelValue[key]) ? [] : void 0;
        } else {
          const val = defaultParams.value[key];
          if (Array.isArray(val)) {
            params[key] = [...val];
          } else if (isObject(val)) {
            params[key] = {
              ...val
            };
          } else {
            params[key] = val;
          }
        }
      }
      context.emit("update:modelValue", params);
      context.emit("reset");
      (_a2 = props.search) == null ? void 0 : _a2.call(props);
    }
    function isObject(val) {
      const type = typeof val;
      return val != null && (type === "object" || type === "function");
    }
    const create = () => {
      var _a2, _b2;
      return ((_b2 = (_a2 = context.slots).create) == null ? void 0 : _b2.call(_a2)) || props.create && vue.createVNode(vue.resolveComponent("bc-button"), {
        "type": "primary",
        "onClick": () => {
          context.emit("create");
        }
      }, {
        default: () => [vue.createTextVNode("\u65B0\u589E")]
      });
    };
    const search = () => {
      var _a2, _b2;
      return ((_b2 = (_a2 = context.slots).search) == null ? void 0 : _b2.call(_a2)) || vue.createVNode(vue.resolveComponent("bc-button"), {
        "type": "primary",
        "onClick": handleSearch
      }, {
        default: () => [vue.createTextVNode("\u641C\u7D22")]
      });
    };
    const reset = () => {
      var _a2, _b2;
      return ((_b2 = (_a2 = context.slots).reset) == null ? void 0 : _b2.call(_a2)) || vue.createVNode(vue.resolveComponent("bc-button"), {
        "type": "primary",
        "class": "el-icon-refresh",
        "onClick": handleReset
      }, {
        default: () => [vue.createTextVNode("\u91CD\u7F6E")]
      });
    };
    const upload = () => {
      var _a2, _b2;
      return ((_b2 = (_a2 = context.slots).upload) == null ? void 0 : _b2.call(_a2)) || props.upload && vue.createVNode(vue.resolveComponent("bc-button"), {
        "onClick": handleUpload
      }, {
        default: () => [props.upload.text || "\u5BFC\u5165"]
      });
    };
    const exportButton = () => {
      var _a2, _b2;
      return ((_b2 = (_a2 = context.slots).export) == null ? void 0 : _b2.call(_a2)) || needExport && vue.createVNode(vue.resolveComponent("bc-button"), {
        "onClick": () => {
          context.emit("export");
        }
      }, {
        default: () => [vue.createTextVNode("\u5BFC\u51FA")]
      });
    };
    const layout = {
      create,
      search,
      reset,
      upload,
      export: exportButton,
      advance: () => vue.createVNode(vue.Fragment, null, null)
    };
    const node = () => vue.createVNode("section", {
      "class": "bc-search-wraper"
    }, [vue.createVNode(vue.resolveComponent("el-form"), {
      "class": "bc-search-containers",
      "inline": true,
      "onSubmit": handleSubmit
    }, {
      default: () => {
        var _a2;
        return [(_a2 = searchConfig.value) == null ? void 0 : _a2.map((item) => {
          let _slot;
          return vue.createVNode(vue.resolveComponent("el-form-item"), null, _isSlot(_slot = renderUnit.renderUnit(vue.h, props.modelValue, item, {
            handleSearch: props.search,
            updateData,
            context: instance
          })) ? _slot : {
            default: () => [_slot]
          });
        }), vue.createVNode(vue.resolveComponent("el-form-item"), null, {
          default: () => {
            var _a3, _b2;
            return [props.layout.map((item) => layout[item]()), (_b2 = (_a3 = context.slots).default) == null ? void 0 : _b2.call(_a3)];
          }
        })];
      }
    }), props.upload && vue.createVNode(vue.resolveComponent("bc-upload"), vue.mergeProps({
      "modelValue": uploadVisible.value,
      "onUpdate:modelValue": ($event) => uploadVisible.value = $event,
      "onSuccess": handleSearch
    }, props.upload, context.attrs), null)]);
    return node;
  }
});

exports["default"] = Search;
//# sourceMappingURL=search.js.map
