import { ExtractPropTypes, PropType } from 'vue';
import { ApiResponseType } from '@sepveneto/basic-comp/es/components/type';
export type SelectOption = {
    children?: SelectOption[];
    [key: string]: any;
};
export type SelectOptions = SelectOption[];
export type selectApiType = '';
export declare const selectProps: {
    /**
     * 选项列表对应的字段名称，可通过config-provider全局设置
     */
    arrayName: StringConstructor;
    /**
     * 是否需要分组（根据children分组）
     */
    group: BooleanConstructor;
    /**
     * 默认值
     */
    defaultValue: StringConstructor;
    /**
     * 是否自动拉取远程数据
     */
    immediate: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 只读，与readonly类似，通常用于打印
     */
    onlyDisplay: BooleanConstructor;
    /**
     * value为对象时需要设置key
     */
    optionKey: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 选择框的宽度
     */
    width: (StringConstructor | NumberConstructor)[];
    modelValue: (ObjectConstructor | StringConstructor | NumberConstructor | ArrayConstructor)[];
    /**
     * 拉取远程数据时调用的函数，支持promise
     */
    api: {
        type: PropType<() => Promise<ApiResponseType>>;
        validator(val: () => unknown | selectApiType): boolean;
    };
    /**
     * 本地选项列表
     */
    options: {
        type: PropType<SelectOptions>;
    };
    /**
     * 选项中用于展示的字段，可通过config-provider全局设置
     */
    customLabel: {
        type: StringConstructor;
    };
    /**
     * 选项中用于取值的字段，可通过config-provider全局设置
     */
    customValue: {
        type: StringConstructor;
    };
    /**
     * 禁用选项的条件
     */
    itemDisabled: PropType<(val: unknown) => boolean>;
};
export type SelectProps = Partial<ExtractPropTypes<typeof selectProps>>;
