'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
require('../../../utils/index.js');
var cellEdit = require('./cellEdit.js');
var elementPlus = require('element-plus');
var useSelection = require('./useSelection.js');
var tools = require('../../../utils/tools.js');

function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !vue.isVNode(s);
}
var customTable = vue.defineComponent({
  name: "CustomTable",
  emits: ["save", "radio", "select"],
  components: {
    cellEdit: cellEdit["default"],
    ElTable: elementPlus.ElTable,
    ElTableColumn: elementPlus.ElTableColumn,
    ElRadio: elementPlus.ElRadio
  },
  props: {
    emptyText: {
      type: [String, Function],
      default: ""
    },
    rowSelection: {
      type: Object,
      default: () => ({
        selectedRowKeys: [],
        onChange: () => ({})
      })
    },
    rowKey: [String, Function],
    disableTravel: Boolean,
    bodyBorder: Boolean,
    wrapHeader: Boolean,
    showOverflowTooltip: Boolean,
    hiddenCurrent: Boolean,
    rowEdit: Boolean,
    banSelectAll: Boolean,
    refs: String,
    customIcon: Boolean,
    data: {
      type: Array,
      default: () => []
    },
    config: {
      type: Array,
      default: () => []
    },
    htmlContent: Boolean
  },
  setup(props, context) {
    const tableConfig = vue.ref([]);
    const radio = vue.ref("");
    const instance = vue.getCurrentInstance();
    const tableRef = vue.ref();
    const rowSelection = vue.ref();
    vue.watch(() => props.rowSelection, () => {
      rowSelection.value = props.rowSelection ? {
        ...props.rowSelection
      } : props.rowSelection;
    }, {
      deep: true,
      immediate: true
    });
    const [renderSelect, renderSelectTop] = useSelection.useSelection(rowSelection, {
      pageData: vue.computed(() => props.data),
      getRowKey,
      getRecordByKey: getRowByKey
    });
    vue.watch(() => props.config, (config) => {
      tableConfig.value = [...config];
    }, {
      immediate: true,
      deep: true
    });
    function clearSelection() {
      tableRef.value.clearSelection();
    }
    function getRowKey(row, rowKey = props.rowKey, index) {
      if (!rowKey) {
        console.warn("\u6CA1\u6709\u8BBE\u7F6Erow-key\uFF0C\u4E0D\u63A8\u8350\u4F7F\u7528index\u4F5C\u4E3Akey");
        return index;
      }
      if (typeof rowKey === "function") {
        return rowKey(row);
      } else if (row[rowKey]) {
        return row[rowKey];
      } else {
        return false;
      }
    }
    function getRowByKey(key) {
      return props.data.find((item) => getRowKey(item) === key);
    }
    const renderRadio = (row, index, config) => vue.createVNode(vue.resolveComponent("el-radio"), vue.mergeProps({
      "model-value": radio.value
    }, {
      "onUpdate:modelValue": (val) => {
        radio.value = val;
        context.emit("radio", radio.value, row);
        context.emit("select", [row]);
      }
    }, {
      "label": getRowKey(row, props.rowKey, index),
      "disabled": config.selectable ? !config.selectable(row) : false
    }), {
      default: () => [vue.createVNode("span", null, null)]
    });
    const renderCellEdit = (row, column, config) => vue.createVNode(vue.resolveComponent("cell-edit"), {
      "modelValue": tools.getValue(row, column.property, config, props.disableTravel),
      "onBlur": (val) => {
        tools.setValue(row, column.property, val);
      },
      "onSave": (cell) => {
        var _a;
        (_a = instance == null ? void 0 : instance.parent) == null ? void 0 : _a.emit("save", cell, column.property);
      }
    }, null);
    const getColumnSlot = (data, config) => {
      var _a, _b;
      if (config.children && config.children.length > 0) {
        return config.children.map((config2) => transformTableColumn(config2));
      }
      const {
        row,
        column,
        $index
      } = data;
      if (config.type === "expand") {
        return (_b = (_a = context.slots).expand) == null ? void 0 : _b.call(_a, data);
      } else if (config.type === "radio") {
        if (!~$index) {
          return;
        }
        return renderRadio(row, $index, config);
      } else if (config.editable) {
        return renderCellEdit(row, column, config);
      }
      if (!column.property) {
        return null;
      }
      const slot = context.slots[config.prop];
      const value = tools.getValue(row, column.property, config, props.disableTravel);
      const realValue = typeof props.emptyText === "function" ? props.emptyText(value, column) : value === "" ? props.emptyText : value;
      return slot ? slot(data) : vue.createVNode("span", null, [realValue]);
    };
    const transformTableColumn = (config) => {
      if (!config) {
        return null;
      }
      if (config.type === "select") {
        return vue.createVNode(vue.resolveComponent("el-table-column"), {
          "width": "48px"
        }, {
          default: (data) => renderSelect(data, config),
          header: () => renderSelectTop()
        });
      }
      if (config.type === "selection") {
        return vue.createVNode(vue.resolveComponent("el-table-column"), config, null);
      }
      return vue.createVNode(vue.resolveComponent("el-table-column"), vue.mergeProps({
        "show-overflow-tooltip": props.showOverflowTooltip
      }, tools.extractObject(config, ["children"], "exclude")), {
        default: (data) => getColumnSlot(data, config),
        header: ({
          column,
          $index
        }) => {
          const header = context.slots[`${config.prop}-header`];
          return header ? header({
            column,
            $index
          }) : vue.createVNode("span", null, [column.label]);
        }
      });
    };
    context.expose({
      clearSelection,
      getRef: () => tableRef.value
    });
    return {
      tableRef,
      tableConfig,
      transformTableColumn
    };
  },
  render() {
    let _slot;
    return vue.createVNode(vue.resolveComponent("el-table"), vue.mergeProps({
      "class": ["custom-table", {
        "cutom-icon": this.customIcon
      }, {
        "current-hover": this.hiddenCurrent
      }],
      "ref": this.tableRef,
      "border": true,
      "data": this.data,
      "header-cell-class-name": "custom-header",
      "row-key": this.rowKey,
      "onSelect": (...args) => this.$emit.apply(this, ["select", ...args]),
      "size": "default"
    }, this.$attrs), _isSlot(_slot = this.tableConfig.map((config) => this.transformTableColumn(config))) ? _slot : {
      default: () => [_slot]
    });
  }
});

exports["default"] = customTable;
//# sourceMappingURL=customTable.js.map
