'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
require('../../../hooks/index.js');
var customTable = require('./customTable.js');
var pagination = require('./pagination.js');
var type = require('./type.js');
var useConfigInject = require('../../../hooks/useConfigInject.js');

var Table = vue.defineComponent({
  name: "BcTable",
  emits: ["update:modelValue"],
  components: {
    customTable: customTable["default"],
    customPagination: pagination["default"]
  },
  props: type.tableProps,
  setup(props, context) {
    const {
      arrayName,
      pageSizeName,
      pageName,
      response,
      table
    } = useConfigInject.useConfigInject("bcTable", props);
    const arrayData = vue.ref([]);
    const arrayTotal = vue.ref(0);
    const simpleTable = vue.reactive({
      page: 1,
      rows: 5
    });
    const loading = vue.ref(false);
    const tableConfig = vue.ref([{}]);
    const customTableRef = vue.ref();
    const configProviderTable = vue.computed(() => table.value);
    const responseWrap = vue.computed(() => {
      var _a, _b;
      return (_b = (_a = response.value) == null ? void 0 : _a.data) != null ? _b : "data";
    });
    const tableDataName = vue.computed(() => {
      var _a;
      if (props.arrayName == null) {
        return null;
      } else {
        return (_a = props.arrayName || arrayName.value) != null ? _a : "";
      }
    });
    const tableData = vue.computed(() => {
      if (props.data && props.data.length > 0) {
        return [...props.data || []];
      } else {
        return props.filter ? props.filter(arrayData.value) : [...arrayData.value];
      }
    });
    const totalColumn = vue.computed(() => {
      const {
        includes = [],
        parentProp = null
      } = props.colspanOptions;
      const totalColumn2 = {};
      const whiteList = {};
      includes.forEach((item) => {
        whiteList[item] = 0;
      });
      tableData.value.forEach((row) => {
        Object.keys(row).forEach((key) => {
          if (!Object.keys(whiteList).includes(key)) {
            return;
          }
          const spanKey = parentProp ? `${row[parentProp]}_${key}_${row[key]}` : `${key}_${row[key]}`;
          const column = totalColumn2[spanKey];
          if (!row[key]) {
            whiteList[key] += 1;
            return;
          }
          if (column != null) {
            Object.assign(totalColumn2[spanKey], {
              num: column.num + 1
            });
          } else {
            totalColumn2[spanKey] = {
              index: whiteList[key],
              num: 1
            };
          }
          whiteList[key] += 1;
        });
      });
      return totalColumn2;
    });
    const searchModel = vue.computed({
      get() {
        const {
          [pageName.value]: page,
          [pageSizeName.value]: rows,
          ...params
        } = props.modelValue;
        return {
          page,
          rows,
          ...params
        };
      },
      set(obj) {
        updateParams(obj);
      }
    });
    const simpleData = vue.computed(() => {
      var _a;
      const {
        page,
        rows
      } = simpleTable;
      const start = (page - 1) * rows;
      const end = page * rows;
      return (_a = props.data) == null ? void 0 : _a.slice(start, end);
    });
    vue.watch(() => props.config, (config) => {
      config && (tableConfig.value = [...config]);
    }, {
      deep: true,
      immediate: true
    });
    if (props.activatedUpdate) {
      vue.onActivated(() => {
        init();
      });
    }
    init();
    function init() {
      if (props.custom) {
        props.api && props.immediate && props.api();
      } else {
        if (props.load && props.immediate && props.api) {
          loading.value = true;
        }
        props.api && props.immediate && getList();
      }
    }
    function getList() {
      var _a;
      if (!props.custom && props.load) {
        loading.value = true;
      }
      const wrap = responseWrap.value;
      const array = tableDataName.value;
      return (_a = props.api) == null ? void 0 : _a.call(props).then((data) => {
        var _a2, _b;
        arrayData.value = (array ? data[wrap][array] : data[wrap]) || [];
        loading.value = false;
        arrayTotal.value = data[wrap][(_b = (_a2 = table.value) == null ? void 0 : _a2.totalName) != null ? _b : "total"] || 0;
        return Promise.resolve(arrayData.value);
      }).catch(() => {
        loading.value = false;
        arrayData.value = [];
        arrayTotal.value = 0;
      });
    }
    function updateParams(params) {
      var _a, _b, _c, _d;
      const pageName2 = (_b = (_a = configProviderTable.value) == null ? void 0 : _a.pageName) != null ? _b : "page";
      const pageSizeName2 = (_d = (_c = configProviderTable.value) == null ? void 0 : _c.pageSizeName) != null ? _d : "rows";
      const {
        page,
        rows,
        ...args
      } = params;
      context.emit("update:modelValue", {
        ...args,
        [pageName2]: page,
        [pageSizeName2]: rows
      });
    }
    function spanMethod({
      row,
      column,
      rowIndex
    }) {
      const {
        includes = [],
        parentProp = null
      } = props.colspanOptions;
      const key = column.property;
      const spanKey = parentProp ? `${row[parentProp]}_${key}_${row[key]}` : `${key}_${row[key]}`;
      if (!includes.includes(key) || row[key] == null) {
        return {
          colspan: 1,
          rowspan: 1
        };
      }
      if (rowIndex === totalColumn.value[spanKey].index) {
        return {
          colspan: 1,
          rowspan: totalColumn.value[spanKey].num
        };
      } else {
        return [0, 0];
      }
    }
    function handlePageChange(page) {
      var _a;
      searchModel.value.page = page;
      updateParams(searchModel.value);
      props.custom ? (_a = props.api) == null ? void 0 : _a.call(props) : getList();
    }
    function handleRowsChange(rows) {
      searchModel.value.rows = rows;
      handlePageChange(1);
    }
    function handleSimplePageChange(page) {
      simpleTable.page = page;
    }
    function handleSimpleRowsChange(rows) {
      simpleTable.rows = rows;
    }
    const pagination = () => {
      if (!props.pagination) {
        return null;
      }
      return props.simple ? vue.createVNode(vue.resolveComponent("custom-pagination"), vue.mergeProps({
        "currentPage": simpleTable.page,
        "onUpdate:currentPage": ($event) => simpleTable.page = $event,
        "pageSize": simpleTable.rows,
        "onUpdate:pageSize": ($event) => simpleTable.rows = $event
      }, {
        "onUpdate:currentPage": handleSimplePageChange,
        "onUpdate:pageSize": handleSimpleRowsChange
      }, {
        "total": tableData.value.length,
        "layout": "prev, pager, next"
      }), null) : vue.createVNode(vue.resolveComponent("custom-pagination"), vue.mergeProps({
        "currentPage": searchModel.value.page,
        "onUpdate:currentPage": ($event) => searchModel.value.page = $event,
        "pageSize": searchModel.value.rows,
        "onUpdate:pageSize": ($event) => searchModel.value.rows = $event
      }, {
        "onUpdate:currentPage": handlePageChange,
        "onUpdate:pageSize": handleRowsChange
      }, context.attrs, {
        "total": props.custom ? props.total : arrayTotal.value
      }), null);
    };
    context.expose({
      getList,
      clearSelection: () => customTableRef.value.clearSelection(),
      getRef: () => customTableRef.value.getRef()
    });
    return () => vue.createVNode("section", {
      "class": "bc-table-wrap"
    }, [vue.createVNode(vue.resolveComponent("custom-table"), vue.mergeProps({
      "class": "bc-table",
      "ref": customTableRef,
      "config": tableConfig.value,
      "data": props.simple ? simpleData.value : tableData.value,
      "span-method": props.colspanOptions ? spanMethod : null,
      "hidden-current": !!props.colspanOptions,
      "body-border": !!props.colspanOptions
    }, context.attrs), context.slots), pagination()]);
  }
});

exports["default"] = Table;
//# sourceMappingURL=table.js.map
