import { PropType, ExtractPropTypes } from 'vue';
import { TableColumnCtx } from 'element-plus/lib/components/table/src/table-column/defaults';
export type CellType = {
    row: Record<string, unknown>;
    rowIndex: number;
    column: TableColumnCtx<unknown>;
    columnIndex: number;
};
export type Colspanoptions = {
    includes: string[];
    parentProp: string;
};
export declare const tableProps: {
    /**
     * 远程获取表格数据的字段名，可通过config-provider全局设置，默认rows
     */
    arrayName: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 列合并的相关设置
     */
    colspanOptions: {
        type: PropType<Colspanoptions>;
        default: () => {};
    };
    /**
     * 表格的内边距
     */
    padding: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 自定义表格数据（也就是常规的elementui table的用法）
     */
    custom: BooleanConstructor;
    /**
     * 表格数据
     */
    data: ArrayConstructor;
    /**
     * 表格数据的过滤器
     */
    filter: FunctionConstructor;
    /**
     * 针对远程数据，是否需要自动获取（created阶段请求数据）
     */
    immediate: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 是否开启分页功能
     */
    pagination: BooleanConstructor;
    /**
     * 远程数据获取的回调函数，支持promise
     */
    api: FunctionConstructor;
    /**
     * 分页参数，支持双向绑定
     */
    modelValue: {
        type: PropType<Record<string, unknown>>;
        default: () => {
            page: number;
            rows: number;
        };
    };
    /**
     * 表格列的配置
     */
    config: {
        type: PropType<Record<string, unknown>[]>;
        default: () => never[];
    };
    /**
     * 常规用法下开启分页功能，需要的总数
     */
    total: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 固定底部的横向滚动条（Beta）
     */
    fixXScroll: BooleanConstructor;
    /**
     * 简易表格，支持本地分页
     */
    simple: BooleanConstructor;
    /**
     * 是否开启接口请求时的loading过渡
     */
    load: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 是否禁用activated时自动触发列表更新
     */
    activatedUpdate: {
        type: BooleanConstructor;
    };
};
export type TableProps = Partial<ExtractPropTypes<typeof tableProps>>;
